@@ -1,7 +1,8 @@
 package Email::Sender::Transport::SMTP;
-our $VERSION = '0.100460';
-use Moose;
-with 'Email::Sender::Transport' => { excludes => 'allow_partial_success' };
+BEGIN {
+  $Email::Sender::Transport::SMTP::VERSION = '0.102370';
+}
+use Moose 0.90;
 # ABSTRACT: send email over SMTP
 
 use Email::Sender::Failure::Multi;
@@ -27,7 +28,7 @@ has sasl_password => (is => 'ro', isa => 'Str');
 has allow_partial_success => (is => 'ro', isa => 'Bool', default => 0);
 
 
-has helo      => (is => 'ro', isa => 'Str'); # default to hostname_long
+has helo      => (is => 'ro', isa => 'Str');
 has localaddr => (is => 'ro');
 has localport => (is => 'ro', isa => 'Int');
 
@@ -78,9 +79,9 @@ sub _net_smtp_args {
     $self->host,
     Port    => $self->port,
     Timeout => $self->timeout,
-    $self->helo      ? (Hello     => $self->helo)      : (),
-    $self->localaddr ? (LocalAddr => $self->localaddr) : (),
-    $self->localport ? (LocalPort => $self->localport) : (),
+    defined $self->helo      ? (Hello     => $self->helo)      : (),
+    defined $self->localaddr ? (LocalAddr => $self->localaddr) : (),
+    defined $self->localport ? (LocalPort => $self->localport) : (),
   );
 }
 
@@ -190,6 +191,7 @@ sub partial_success {
 sub _message_complete { $_[1]->quit; }
 
 
+with 'Email::Sender::Transport';
 __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
@@ -203,7 +205,7 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 0.100460
+version 0.102370
 
 =head1 DESCRIPTION
 
@@ -250,7 +252,7 @@ documentation.
 
 =head1 AUTHOR
 
-  Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
